Mahyar Samani has uploaded this change for review. (
https://gem5-review.googlesource.com/c/public/gem5/+/31866 )
Change subject: mem: Update DRAMSim3 functionlity to tick only in timing
mode
......................................................................
mem: Update DRAMSim3 functionlity to tick only in timing mode
Change-Id: I8d2e55a7e9ed7b68862491e6694a96936a2acb18
---
M src/mem/dramsim3.cc
1 file changed, 9 insertions(+), 6 deletions(-)
diff --git a/src/mem/dramsim3.cc b/src/mem/dramsim3.cc
index fdab85b..ef275b0 100644
--- a/src/mem/dramsim3.cc
+++ b/src/mem/dramsim3.cc
@@ -138,13 +138,16 @@
void
DRAMSim3::tick()
{
- wrapper.tick();
+ // Only tick when it's timing mode
+ if (system()->isTimingMode()) {
+ wrapper.tick();
- // is the connected port waiting for a retry, if so check the
- // state and send a retry if conditions have changed
- if (retryReq && nbrOutstanding() < wrapper.queueSize()) {
- retryReq = false;
- port.sendRetryReq();
+ // is the connected port waiting for a retry, if so check the
+ // state and send a retry if conditions have changed
+ if (retryReq && nbrOutstanding() < wrapper.queueSize()) {
+ retryReq = false;
+ port.sendRetryReq();
+ }
}
schedule(tickEvent, curTick() + wrapper.clockPeriod() *
SimClock::Int::ns);
--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/31866
To unsubscribe, or for help writing mail filters, visit
https://gem5-review.googlesource.com/settings
Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I8d2e55a7e9ed7b68862491e6694a96936a2acb18
Gerrit-Change-Number: 31866
Gerrit-PatchSet: 1
Gerrit-Owner: Mahyar Samani <[email protected]>
Gerrit-MessageType: newchange
_______________________________________________
gem5-dev mailing list -- [email protected]
To unsubscribe send an email to [email protected]
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s